@@ -26,8 +26,8 @@
 */
 
 
-#ifndef KP_TOOL_AUTO_CROP_H
-#define KP_TOOL_AUTO_CROP_H
+#ifndef KP_TRANSFORM_AUTO_CROP_H
+#define KP_TRANSFORM_AUTO_CROP_H
 
 
 #include "commands/kpNamedCommand.h"
@@ -82,4 +82,4 @@ private:
 bool kpTransformAutoCrop (kpMainWindow *mainWindow);
 
 
-#endif  // KP_TOOL_AUTO_CROP_H
+#endif  // KP_TRANSFORM_AUTO_CROP_H
